@@ -18,14 +18,6 @@
 ### Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 ### MA 02110-1301, USA
 
-
-
-
-
-
-
-
-
 prepanel.default.densityplot <-
     function(x,
              darg,
@@ -62,7 +54,7 @@ prepanel.default.densityplot <-
     else
     {
         vals <- sort(unique(groups))
-        nvals <- length(vals)
+        ## nvals <- length(vals)
         xl <- range(x, finite = TRUE)
         yl <- 0
         dxl <- numeric(0) # bad names !!
@@ -98,7 +90,7 @@ prepanel.default.densityplot <-
 
 panel.densityplot <-
     function(x,
-             darg = list(n = 30),
+             darg = list(n = 512),
              plot.points = "jitter",
              ref = FALSE,
              groups = NULL,
@@ -110,7 +102,8 @@ panel.densityplot <-
 ##              col.line = if (is.null(groups)) plot.line$col else superpose.line$col,
              jitter.amount = 0.01 * diff(current.panel.limits()$ylim),
              type = "p",
-             ...)
+             ...,
+             identifier = "density")
 {
     if (ref)
     {
@@ -118,7 +111,8 @@ panel.densityplot <-
         panel.abline(h = 0,
                      col = reference.line$col,
                      lty = reference.line$lty,
-                     lwd = reference.line$lwd)
+                     lwd = reference.line$lwd,
+                     identifier = paste(identifier, "abline"))
     }
     ## plot.line <- trellis.par.get("plot.line")
     ## superpose.line <- trellis.par.get("superpose.line")
@@ -137,18 +131,21 @@ panel.densityplot <-
     {
         switch(as.character(plot.points),
                "TRUE" =
-               panel.xyplot(x = x, y = rep(0, length(x)), type = type, ...),
+               panel.xyplot(x = x, y = rep(0, length(x)), type = type, ...,
+                            identifier = identifier),
                "rug" =
                panel.rug(x = x, 
                          start = 0, end = 0,
                          x.units = c("npc", "native"),
                          type = type,
-                         ...),
+                         ...,
+                         identifier = paste(identifier, "rug")),
                "jitter" =
                panel.xyplot(x = x,
                             y = jitter(rep(0, length(x)), amount = jitter.amount),
                             type = type,
-                            ...))
+                            ...,
+                            identifier = identifier))
         density.fun <- function(x, weights, subscripts = TRUE, darg, ...)
             ## wrapper to handle 'subscripts' without actually making
             ## it a formal argument to panel.densityplot
@@ -163,7 +160,8 @@ panel.densityplot <-
             h <- density.fun(x = x, weights = weights, ..., darg = darg)
             lim <- current.panel.limits()$xlim
             id <- h$x > min(lim) & h$x < max(lim)
-            panel.lines(x = h$x[id], y = h$y[id], ...)
+            panel.lines(x = h$x[id], y = h$y[id], ...,
+                        identifier = identifier)
         }
     }
 }
@@ -218,7 +216,7 @@ densityplot.formula <-
              window = NULL,
              width = NULL,
              give.Rkern = FALSE,
-             n = 50,
+             n = 512,
              from = NULL,
              to = NULL,
              cut = NULL,
@@ -298,7 +296,8 @@ densityplot.formula <-
                        ylab = ylab,
                        xlab.default = form$right.name,
                        ylab.default = gettext("Density"),
-                       lattice.options = lattice.options), dots))
+                       lattice.options = lattice.options), dots),
+                quote = TRUE)
 
     dots <- foo$dots # arguments not processed by trellis.skeleton
     foo <- foo$foo
